@@ -3,6 +3,9 @@
 int get_block_size(int algorithm);
 int get_key_size(int algorithm); /* returns key in bytes */
 
+int is_ok_algorithm(int algorithm); /* if this algorithm exists returns 0 */
+int is_ok_mode(int mode); /* if this mode exists returns 0 */
+
 char* get_algorithms_name(int algorithm);
 
 int init_mcrypt ( const int algorithm, int thread, void * key, int lenofkey);
@@ -41,12 +44,27 @@ int init_mcrypt_ofb( const int algorithm, void * key, int lenofkey, void *IV);
 # define GOST 4
 
 #ifdef MCRYPT2
-# define CRYPT 5
+# define CRYPT 50
+# define DES_COMPAT 51
 #endif
 
 # define SAFER64 6
 # define SAFER128 7
 # define CAST128 8
 # define TEAN 9
-# define TWOFISH 10
 # define RC2 11
+# define TWOFISH128 10
+# define TWOFISH192 12
+# define TWOFISH256 13
+
+#ifdef NON_FREE
+# define RC6 100
+# define IDEA 101
+#endif
+
+/* Only needed in mcrypt */
+
+#define CBC 0
+#define ECB 1
+#define CFB 2
+#define OFB 3
